@@ -1,7 +1,7 @@
 """ETS Project Parser is a library to parse ETS project files."""
 # flake8: noqa
-from .knxproj import KNXProj
+from .xknxproj import XKNXProj
 
 __all__ = [
-    "KNXProj",
+    "XKNXProj",
 ]
