@@ -1,10 +1,10 @@
 """Xknxproj models."""
 from .knxproject import (
     Area,
+    CommunicationObject,
     Device,
     Flags,
     GroupAddress,
-    GroupAddressAssignment,
     KNXProject,
     Line,
     Space,
@@ -12,6 +12,7 @@ from .knxproject import (
 from .models import (
     ComObject,
     ComObjectInstanceRef,
+    ComObjectRef,
     DeviceInstance,
     Hardware,
     XMLArea,
@@ -19,12 +20,12 @@ from .models import (
     XMLLine,
     XMLSpace,
 )
-from .static import MANUFACTURERS, MEDIUM_TYPES, SpaceType
+from .static import MEDIUM_TYPES, SpaceType
 
 __all__ = [
     "Area",
     "Line",
-    "GroupAddressAssignment",
+    "CommunicationObject",
     "GroupAddress",
     "Device",
     "Flags",
@@ -32,6 +33,7 @@ __all__ = [
     "XMLArea",
     "ComObject",
     "ComObjectInstanceRef",
+    "ComObjectRef",
     "SpaceType",
     "Space",
     "DeviceInstance",
@@ -39,6 +41,5 @@ __all__ = [
     "XMLLine",
     "XMLSpace",
     "Hardware",
-    "MANUFACTURERS",
     "MEDIUM_TYPES",
 ]
