@@ -1,5 +1,7 @@
 """Define output type for parsed KNX project."""
-from typing import Any, Optional, TypedDict
+from __future__ import annotations
+
+from typing import Any, TypedDict
 
 
 class Flags(TypedDict):
@@ -13,10 +15,11 @@ class Flags(TypedDict):
     read_on_init: bool
 
 
-class GroupAddressAssignment(TypedDict):
-    """Group address assignments dictionary."""
+class CommunicationObject(TypedDict):
+    """Communication object dictionary."""
 
-    co_name: str
+    name: str | None
+    device_address: str
     dpt_type: dict[str, int]
     group_address_links: list[str]
     flags: Flags
@@ -30,7 +33,7 @@ class Device(TypedDict):
     description: str
     manufacturer_name: str
     individual_address: str
-    group_address_assignments: list[GroupAddressAssignment]
+    communication_object_ids: list[str]
 
 
 class Line(TypedDict):
@@ -38,7 +41,7 @@ class Line(TypedDict):
 
     name: str
     medium_type: str
-    description: str
+    description: str | None
     devices: list[str]
 
 
@@ -46,7 +49,7 @@ class Area(TypedDict):
     """Area typed dict."""
 
     name: str
-    description: str
+    description: str | None
     lines: dict[str, Line]
 
 
@@ -57,7 +60,9 @@ class GroupAddress(TypedDict):
     identifier: str
     raw_address: int
     address: str
-    dpt_type: Optional[dict[str, int]]
+    dpt_type: dict[str, int] | None
+    communication_object_ids: list[str]
+    description: str
 
 
 class Space(TypedDict):
@@ -72,6 +77,7 @@ class KNXProject(TypedDict):
     """KNXProject typed dictionary."""
 
     version: str
+    communication_objects: dict[str, CommunicationObject]
     devices: dict[str, Device]
     topology: dict[str, Area]
     locations: dict[str, Space]
