@@ -4,21 +4,18 @@ from __future__ import annotations
 from xknxproject.__version__ import __version__
 from xknxproject.loader import (
     ApplicationProgramLoader,
-    GroupAddressLoader,
     HardwareLoader,
-    LocationLoader,
-    TopologyLoader,
-    XMLLoader,
+    ManufacturerLoader,
+    ProjectLoader,
 )
 from xknxproject.models import (
-    MANUFACTURERS,
     MEDIUM_TYPES,
     Area,
+    CommunicationObject,
     Device,
     DeviceInstance,
     Flags,
     GroupAddress,
-    GroupAddressAssignment,
     Hardware,
     KNXProject,
     Line,
@@ -27,56 +24,54 @@ from xknxproject.models import (
     XMLGroupAddress,
     XMLSpace,
 )
-from xknxproject.zip import KNXProjExtractor
+from xknxproject.zip.extractor import KNXProjContents
 
 
 class XMLParser:
     """Class that parses XMLs and returns useful information."""
 
-    def __init__(self, extractor: KNXProjExtractor):
+    def __init__(self, knx_proj_contents: KNXProjContents) -> None:
         """Initialize the parser."""
-        self.extractor = extractor
-        self.hardware_loader: XMLLoader = HardwareLoader()
-        self.group_address_loader: XMLLoader | None = None
-        self.topology_loader: XMLLoader | None = None
+        self.knx_proj_contents = knx_proj_contents
         self.spaces: list[XMLSpace] = []
         self.group_addresses: list[XMLGroupAddress] = []
         self.hardware: list[Hardware] = []
         self.areas: list[XMLArea] = []
         self.devices: list[DeviceInstance] = []
 
-    async def parse(self) -> KNXProject:
+    def parse(self) -> KNXProject:
         """Parse ETS files."""
-        await self.load()
+        self.load()
 
+        communication_objects: dict[str, CommunicationObject] = {}
         devices_dict: dict[str, Device] = {}
         for device in self.devices:
-            group_address_assignments: list[GroupAddressAssignment] = []
-            for link in device.com_object_instance_refs:
-                if len(link.links) > 0:
-                    group_address_assignments.append(
-                        GroupAddressAssignment(
-                            co_name=link.text,
-                            dpt_type=link.data_point_type,
-                            flags=Flags(
-                                read=True,
-                                write=True,
-                                communication=True,
-                                update=True,
-                                read_on_init=True,
-                                transmit=False,
-                            ),
-                            group_address_links=link.links,
-                        )
+            device_com_objects: list[str] = []
+            for com_object in device.com_object_instance_refs:
+                if com_object.links:
+                    communication_objects[com_object.ref_id] = CommunicationObject(
+                        name=com_object.name or com_object.text,
+                        device_address=device.individual_address,
+                        dpt_type=com_object.datapoint_type,  # type: ignore[typeddict-item]
+                        flags=Flags(
+                            read=com_object.read_flag,  # type: ignore[typeddict-item]
+                            write=com_object.write_flag,  # type: ignore[typeddict-item]
+                            communication=com_object.communication_flag,  # type: ignore[typeddict-item]
+                            update=com_object.update_flag,  # type: ignore[typeddict-item]
+                            read_on_init=com_object.read_on_init_flag,  # type: ignore[typeddict-item]
+                            transmit=com_object.transmit_flag,  # type: ignore[typeddict-item]
+                        ),
+                        group_address_links=com_object.links,
                     )
+                    device_com_objects.append(com_object.ref_id)
 
             devices_dict[device.individual_address] = Device(
                 name=device.name or device.product_name,
                 product_name=device.product_name,
                 description=device.hardware_name,
                 individual_address=device.individual_address,
-                manufacturer_name=MANUFACTURERS.get(device.manufacturer, "Unknown"),
-                group_address_assignments=group_address_assignments,
+                manufacturer_name=device.manufacturer_name,
+                communication_object_ids=device_com_objects,
             )
 
         topology_dict: dict[str, Area] = {}
@@ -98,12 +93,19 @@ class XMLParser:
 
         group_address_dict: dict[str, GroupAddress] = {}
         for group_address in self.group_addresses:
+            _com_object_ids = [
+                com_object_id
+                for com_object_id, com_object in communication_objects.items()
+                if group_address.identifier in com_object["group_address_links"]
+            ]
             group_address_dict[group_address.identifier] = GroupAddress(
                 name=group_address.name,
                 identifier=group_address.identifier,
                 raw_address=group_address.raw_address,
                 address=group_address.address,
                 dpt_type=group_address.dpt_type,
+                communication_object_ids=_com_object_ids,
+                description=group_address.description,
             )
 
         space_dict: dict[str, Space] = {}
@@ -112,6 +114,7 @@ class XMLParser:
 
         return KNXProject(
             version=__version__,
+            communication_objects=communication_objects,
             topology=topology_dict,
             devices=devices_dict,
             group_addresses=group_address_dict,
@@ -126,29 +129,44 @@ class XMLParser:
 
         return Space(type=space.type.value, devices=space.devices, spaces=subspaces)
 
-    async def load(self) -> None:
+    def load(self) -> None:
         """Load XML files."""
-        self.group_address_loader = GroupAddressLoader(self.extractor.get_project_id())
-        self.topology_loader = TopologyLoader(self.extractor.get_project_id())
+        (
+            self.group_addresses,
+            self.areas,
+            self.devices,
+            self.spaces,
+        ) = ProjectLoader.load(self.knx_proj_contents)
 
-        self.group_addresses = await self.group_address_loader.load(
-            self.extractor.extraction_path
+        ManufacturerLoader.load(
+            self.knx_proj_contents.root_path / "knx_master.xml", self.devices
         )
-        self.hardware = await self.hardware_loader.load(self.extractor.extraction_path)
-        self.areas = await self.topology_loader.load(self.extractor.extraction_path)
 
-        for area in self.areas:
-            for line in area.lines:
-                self.devices.extend(line.devices)
-
-        application_program_loader = ApplicationProgramLoader(self.devices)
-        await application_program_loader.load(self.extractor.extraction_path)
-
-        location_loader = LocationLoader(self.extractor.get_project_id(), self.devices)
-        self.spaces = await location_loader.load(self.extractor.extraction_path)
+        for _hardware in [
+            HardwareLoader.load(hardware_file)
+            for hardware_file in HardwareLoader.get_hardware_files(
+                self.knx_proj_contents
+            )
+        ]:
+            self.hardware.extend(_hardware)
 
         for hardware in self.hardware:
             for device in self.devices:
-                if device.hardware_program_ref == hardware.identifier:
+                if device.hardware_ref == hardware.identifier:
                     device.product_name = hardware.name
                     device.hardware_name = hardware.product_name
+
+                    if application_program_ref := hardware.application_program_refs.get(
+                        device.hardware_program_ref
+                    ):
+                        device.application_program_ref = application_program_ref
+                        for com_object in device.com_object_instance_refs:
+                            com_object.update_ref_id(application_program_ref)
+
+        application_programs = (
+            ApplicationProgramLoader.get_application_program_files_for_devices(
+                self.knx_proj_contents.root_path, self.devices
+            )
+        )
+        for application_program_file, devices in application_programs.items():
+            ApplicationProgramLoader.load(application_program_file, devices)
